partis.schema package
=====================

.. toctree::
   :maxdepth: 2

   partis.schema.prim
   partis.schema.valued
   partis.schema.declared
   partis.schema.eval
   partis.schema.module
   partis.schema.plugin
   partis.schema.serialize
